@@ -13,14 +13,16 @@ runLINGAM <- function(X, parentsOf, pointEst, setOptions, directed, verbose,
   if(nrow(X)<=ncol(X)) 
     stop("LINGAM not suitable for high-dimensional data; 
          need nrow(X) > ncol(X)")
-  res <- pcalg::LINGAM(X, verbose=verbose)
-  lingammat <- res$Adj
+  res <- pcalg::lingam(X, verbose=verbose)
+  B <- res$Bpruned
+  B[B != 0] <- 1
+  lingammat <- t(B)
   if(directed) lingammat <- lingammat * (t(lingammat)==0)
   
   for (k in 1:length(parentsOf)){
     result[[k]] <- (wh <- which(lingammat[, parentsOf[k]] == 1)) 
     if(pointEst) 
-      attr(result[[k]],"coefficients") <- t(res$B)[ wh,parentsOf[k]]
+      attr(result[[k]],"coefficients") <- t(res$Bpruned)[ wh,parentsOf[k]]
   }
   
   result
